#include "ft_nm.h"

int check_magic_number(const char *magic_number) {
	if (ft_strncmp(magic_number, "\x7f""ELF", 4)) {
		return FT_NM_FAILURE;
	}
	return FT_NM_SUCCESS;
}

int check_arch(unsigned char arch) {
	if (arch != ELFCLASS64 && arch != ELFCLASS32) {
		return FT_NM_FAILURE;
	}
	return FT_NM_SUCCESS;
}

int check_data_format(unsigned char data_format) {
	if (data_format != ELFDATA2MSB && data_format != ELFDATA2LSB) {
		return FT_NM_FAILURE;
	}
	return FT_NM_SUCCESS;
}

int check_version(unsigned char version) {
	if (version != EV_CURRENT) {
		return FT_NM_FAILURE;
	}
	return FT_NM_SUCCESS;
}

int check_ident(unsigned char ident[EI_NIDENT]) {
	if (check_magic_number((const char *)&ident[EI_MAG0])
			== FT_NM_FAILURE) {
		return FT_NM_FAILURE;
	}
	if (check_arch(ident[EI_CLASS]) == FT_NM_FAILURE) {
		return FT_NM_FAILURE;
	}
	if (check_data_format(ident[EI_DATA]) == FT_NM_FAILURE) {
		return FT_NM_FAILURE;
	}
	if (check_version(ident[EI_VERSION]) == FT_NM_FAILURE) {
		return FT_NM_FAILURE;
	}
	return FT_NM_SUCCESS;
}

